[![Python](https://www.python.org/static/community_logos/python-powered-w-100x40.png)](https://www.python.org)

[![my_CI](https://github.com/shimwell/example_package_for_flf/actions/workflows/ci.yml/badge.svg)](https://github.com/shimwell/example_package_for_flf/actions/workflows/ci.yml)

A python package :snake: to that checks if shapes positioned on the circumference of a circle overlap or not


# installation

To install run this pip command from the terminal

```bash
pip install example_package_for_flf
```

# testing

```bash
pip install does_it_fit[test]
pytest tests
```

# Usage

How to ...

```python
import example_package_for_flf
example_package_for_flf.fits()
```
